/*
 * Copyright 2002, 2003 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or
 * without modification, are permitted provided that the following
 * conditions are met:
 * 
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 * 
 * - Redistribution in binary form must reproduce the above
 *   copyright notice, this list of conditions and the following
 *   disclaimer in the documentation and/or other materials
 *   provided with the distribution.
 *    
 * Neither the name of Sun Microsystems, Inc. or the names of
 * contributors may be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *  
 * This software is provided "AS IS," without a warranty of any
 * kind. ALL EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND
 * WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE HEREBY
 * EXCLUDED. SUN AND ITS LICENSORS SHALL NOT BE LIABLE FOR ANY
 * DAMAGES OR LIABILITIES SUFFERED BY LICENSEE AS A RESULT OF OR
 * RELATING TO USE, MODIFICATION OR DISTRIBUTION OF THIS SOFTWARE OR
 * ITS DERIVATIVES. IN NO EVENT WILL SUN OR ITS LICENSORS BE LIABLE
 * FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR DIRECT, INDIRECT,
 * SPECIAL, CONSEQUENTIAL, INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER
 * CAUSED AND REGARDLESS OF THE THEORY OF LIABILITY, ARISING OUT OF
 * THE USE OF OR INABILITY TO USE THIS SOFTWARE, EVEN IF SUN HAS
 * BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 *  
 * You acknowledge that this software is not designed, licensed or
 * intended for use in the design, construction, operation or
 * maintenance of any nuclear facility.
 */


package carshop;

import java.util.ResourceBundle;
import java.util.ArrayList;

import javax.faces.event.ActionListener;
import javax.faces.event.ActionEvent;
import javax.faces.event.PhaseId;
import javax.faces.context.FacesContext;
import javax.faces.application.ApplicationFactory;
import javax.faces.application.Application;
import javax.faces.FactoryFinder;
import javax.faces.el.ValueBinding;
import javax.faces.component.UIComponent;
import javax.faces.component.UIOutput;
import javax.faces.component.SelectItem;


public class CarActionListener implements ActionListener {
    
    public CarActionListener() {
    }
    
    public PhaseId getPhaseId() {
        return PhaseId.APPLY_REQUEST_VALUES;
    }
    
    public void processAction(ActionEvent event) {
        
        String actionCommand = event.getActionCommand();
        processActionCommand(actionCommand);
        
        ResourceBundle rb = ResourceBundle.getBundle("carshop/Resources", FacesContext.getCurrentInstance().getLocale());
        
        if (actionCommand.equals("custom")) {
            processCustom(event, rb);
        } else if (actionCommand.equals("deluxe")) {
            processDeluxe(event, rb);
        } else if (actionCommand.equals("recalculate")) {
            FacesContext context = FacesContext.getCurrentInstance();           
            ApplicationFactory factory = (ApplicationFactory)FactoryFinder.getFactory("javax.faces.application.ApplicationFactory");
            Application application = factory.getApplication();         
            ValueBinding binding = application.getValueBinding("CurrentOptionServer.currentPackage");
            String currentPackage = (String)binding.getValue(context);
            
            if (currentPackage.equals("custom")) {
                processCustom(event, rb);
            } else if (currentPackage.equals("deluxe")) {
                processDeluxe(event, rb);
            }
        } else if (actionCommand.equals("buy")) {
            FacesContext context = FacesContext.getCurrentInstance();
            ApplicationFactory factory = (ApplicationFactory)FactoryFinder.getFactory("javax.faces.application.ApplicationFactory");
            Application application = factory.getApplication();                 
            ValueBinding currentBinding = application.getValueBinding("CurrentOptionServer.carCurrentPrice");
            String carPrice = (String)currentBinding.getValue(context);
            ValueBinding packageBinding = application.getValueBinding("CurrentOptionServer.packagePrice");
            packageBinding.setValue(context, carPrice);
        }
    }
    
    
    private void processCustom(ActionEvent event, ResourceBundle rb) {
        UIComponent component = event.getComponent();
        int i = 0;
        UIComponent foundComponent = null;
        UIOutput uiOutput = null;
        String value = null;
        boolean packageChange = false;
        
        FacesContext context = FacesContext.getCurrentInstance();
        
        String [] engines = {"V4", "V6", "V8"};
        ArrayList engineOption = new ArrayList(engines.length);
        for (i=0; i<engines.length; i++) {
            engineOption.add(new SelectItem(engines[i], engines[i], engines[i]));
        }
        ApplicationFactory factory = (ApplicationFactory)FactoryFinder.getFactory("javax.faces.application.ApplicationFactory");
        Application application = factory.getApplication();
        ValueBinding eOptionBinding = application.getValueBinding("CurrentOptionServer.engineOption");
        eOptionBinding.setValue(context, engineOption);
        
        foundComponent = component.findComponent("currentEngine");
        uiOutput = (UIOutput)foundComponent;
        if (!((application.getValueBinding("CurrentOptionServer.currentPackage")).getValue(context)).equals("custom")) {
            value = engines[0];
            packageChange = true;
        } else {
            value = (String)uiOutput.getValue();
        }
        uiOutput.setValue(value);
        ValueBinding currentEOBinding = application.getValueBinding("CurrentOptionServer.currentEngineOption");
        currentEOBinding.setValue(context, value);
        
        ValueBinding currentPBinging = application.getValueBinding("CurrentOptionServer.currentPackage");
        currentPBinging.setValue(context, "custom");        
        
        foundComponent = component.findComponent("securitySystem");
        foundComponent.setAttribute("disabled", "false");
        foundComponent.setAttribute("selectbooleanClass", "option-unselected");
        ValueBinding securityBinding = application.getValueBinding("CurrentOptionServer.securitySystem");
        securityBinding.setValue(context, Boolean.FALSE);

        foundComponent = component.findComponent("gps");
        foundComponent.setAttribute("disabled", "false");
        foundComponent.setAttribute("selectbooleanClass", "option-unselected");
        ValueBinding gpsBinding = application.getValueBinding("CurrentOptionServer.gps");
        gpsBinding.setValue(context, Boolean.FALSE);
        
        foundComponent = component.findComponent("custom");
        foundComponent.setAttribute("commandClass", "package-selected");
        
        foundComponent = component.findComponent("deluxe");
        foundComponent.setAttribute("commandClass", "package-unselected");        
    }
    
    
    
    private void processDeluxe(ActionEvent event, ResourceBundle rb) {
        UIComponent component = event.getComponent();
        UIComponent foundComponent = null;
        UIOutput uiOutput = null;   
        String value = null;
        boolean packageChange = false;
        int i = 0;
        
        FacesContext context = FacesContext.getCurrentInstance();
        
        String[] engines = {"V4", "V6", "V8"};
        ArrayList engineOption = new ArrayList(engines.length);
        for (i=0; i<engines.length; i++) {
            engineOption.add(new SelectItem(engines[i], engines[i], engines[i]));
        }
        
        ApplicationFactory factory = (ApplicationFactory)FactoryFinder.getFactory("javax.faces.application.ApplicationFactory");
        Application application = factory.getApplication();
        ValueBinding eOptionBinding = application.getValueBinding("CurrentOptionServer.engineOption");
        eOptionBinding.setValue(context, engineOption);
        
        foundComponent = component.findComponent("currentEngine");
        uiOutput = (UIOutput)foundComponent;
        if (!((application.getValueBinding("CurrentOptionServer.currentPackage")).getValue(context)).equals("deluxe")) {
            value = engines[0];
            packageChange = true;
        } else {
            value = (String)uiOutput.getValue();
        }
        uiOutput.setValue(value);
        ValueBinding currentEOBinding = application.getValueBinding("CurrentOptionServer.currentEngineOption");
        currentEOBinding.setValue(context, value);
        
        ValueBinding currentPBinging = application.getValueBinding("CurrentOptionServer.currentPackage");
        currentPBinging.setValue(context, "deluxe");
        
        foundComponent = component.findComponent("securitySystem");
        foundComponent.setAttribute("disabled", "true");
        ((UIOutput)foundComponent).setValue(Boolean.TRUE);
        foundComponent.setAttribute("selectbooleanClass", "package-selected");
        ValueBinding securityBinding = application.getValueBinding("CurrentOptionServer.securitySystem");
        securityBinding.setValue(context, Boolean.TRUE);

        foundComponent = component.findComponent("gps");
        foundComponent.setAttribute("disabled", "true");
        ((UIOutput)foundComponent).setValue(Boolean.TRUE);
        foundComponent.setAttribute("selectbooleanClass", "package-selected");
        ValueBinding gpsBinding = application.getValueBinding("CurrentOptionServer.gps");
        gpsBinding.setValue(context, Boolean.TRUE);
        
        foundComponent = component.findComponent("custom");
        foundComponent.setAttribute("commandClass", "package-unselected");

        foundComponent = component.findComponent("deluxe");
        foundComponent.setAttribute("commandClass", "package-selected");
    }
    
    
    protected void processActionCommand(String actionCommand) {
        
        FacesContext context = FacesContext.getCurrentInstance();
        ApplicationFactory factory = (ApplicationFactory)FactoryFinder.getFactory("javax.faces.application.ApplicationFactory");
        Application application = factory.getApplication();
        ValueBinding binding = application.getValueBinding("CurrentOptionServer");
        CurrentOptionServer optServer = (CurrentOptionServer)binding.getValue(context);
        
        if (actionCommand.equals("more1")) {
            optServer.setCarId(1);
        } else if (actionCommand.equals("more2")) {
            optServer.setCarId(2);
        } else if (actionCommand.equals("buy")) {
            if (optServer.getCurrentPackage().equals("custom")) {
                optServer.setSecuritySystem(optServer.getSecuritySystemSelected());
                optServer.setGps(optServer.getGpsSelected());
            }
        }
    }
    

    
}