/*
 * Copyright 2002, 2003 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or
 * without modification, are permitted provided that the following
 * conditions are met:
 * 
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 * 
 * - Redistribution in binary form must reproduce the above
 *   copyright notice, this list of conditions and the following
 *   disclaimer in the documentation and/or other materials
 *   provided with the distribution.
 *    
 * Neither the name of Sun Microsystems, Inc. or the names of
 * contributors may be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *  
 * This software is provided "AS IS," without a warranty of any
 * kind. ALL EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND
 * WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE HEREBY
 * EXCLUDED. SUN AND ITS LICENSORS SHALL NOT BE LIABLE FOR ANY
 * DAMAGES OR LIABILITIES SUFFERED BY LICENSEE AS A RESULT OF OR
 * RELATING TO USE, MODIFICATION OR DISTRIBUTION OF THIS SOFTWARE OR
 * ITS DERIVATIVES. IN NO EVENT WILL SUN OR ITS LICENSORS BE LIABLE
 * FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR DIRECT, INDIRECT,
 * SPECIAL, CONSEQUENTIAL, INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER
 * CAUSED AND REGARDLESS OF THE THEORY OF LIABILITY, ARISING OUT OF
 * THE USE OF OR INABILITY TO USE THIS SOFTWARE, EVEN IF SUN HAS
 * BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 *  
 * You acknowledge that this software is not designed, licensed or
 * intended for use in the design, construction, operation or
 * maintenance of any nuclear facility.
 */


package carshop;

import java.util.ResourceBundle;
import java.util.ArrayList;
import java.util.Collection;

import javax.faces.context.FacesContext;
import javax.faces.component.SelectItem;


public class CurrentOptionServer extends Object {
    
    protected int carId = 1;
    protected String thisUrl = "/current.gif";
    protected String engines[] = {
        "V4", "V6", "V8"
    };
    
    protected String carTitle = "You shouldn't see this title";
    protected String carDesc = "This description should never be seen. If it is, your properties files aren't being read.";    

    protected String basePrice = "300";    
    protected String currentPrice = "250";
    protected String packagePrice = "100";
    
    protected String audio[] = null;
    
    protected ArrayList engineOption;
    protected Object currentEngineOption = engines[0];
    protected ArrayList audioOption;
    protected Object currentAudioOption = null;
    protected boolean securitySystem = false;
    protected boolean securitySystemSelected = false;
    protected boolean gps = false;
    protected boolean gpsSelected = false;
    
    protected String currentPackage = "custom";
    
    /** Creates a new instance of CurrentOption */
    public CurrentOptionServer() {
        super();
        loadOptions();
    }
    
    public void loadOptions() {
        ResourceBundle rb = ResourceBundle.getBundle("carshop/Resources", (FacesContext.getCurrentInstance().getLocale()));
        audio = new String[2];
        audio[0] = (String)rb.getObject("Standard");
        audio[1] = (String)rb.getObject("Premium");
        
        currentAudioOption = audio[0];
        
        engineOption = new ArrayList(engines.length);
        audioOption = new ArrayList(audio.length);
        
        int i = 0;
        
        for (i = 0; i < engines.length; i++) {
            engineOption.add(new SelectItem(engines[i], engines[i], engines[i]));
        }
        for (i = 0; i < audio.length; i++) {
            audioOption.add(new SelectItem(audio[i], audio[i], audio[i]));
        }
        
    }
    
    public void setCarId(int id) {
        
        try {
            ResourceBundle rb;
            
            switch (id) {
                
                case 1:
                    String optionsOne = "carshop/CarOptions1";
                    rb = ResourceBundle.getBundle(optionsOne, (FacesContext.getCurrentInstance().getLocale()));
                    setCarImage("/200x168_Roadster.jpg");                    
                    break;
                    
                case 2:
                    String optionsTwo = "carshop/CarOptions2";
                    rb = ResourceBundle.getBundle(optionsTwo, (FacesContext.getCurrentInstance().getLocale()));
                    setCarImage("/200x168_SUV.jpg");                
                    break;
                   
                default:
                    optionsOne = "carshop/CarOptions1";
                    rb = ResourceBundle.getBundle(optionsOne, (FacesContext.getCurrentInstance().getLocale()));            
                    break;
                                     
            }
            
            this.setCarTitle((String)rb.getObject("CarTitle"));
            this.setCarDesc((String)rb.getObject("CarDesc"));
            this.setCarBasePrice((String)rb.getObject("CarBasePrice"));
            this.setCarCurrentPrice((String)rb.getObject("CarCurrentPrice"));
            loadOptions();               
        } catch (Exception ex) {
            System.out.println("Exception in CurrentOptionServer: " + ex.toString());
        }
    }
            

     public int getCarId() {
         return carId;
     }
     
     public void setCarImage(String url) {
         thisUrl = url;
     }
     
     public String getCarImage() {
         return thisUrl;
     }
     
     public void setEngineOption(Collection eng) {
         engineOption = new ArrayList(eng);
     }
     
     public Collection getEngineOption() {
         return engineOption;
     }
     
    public void setCurrentEngineOption(Object eng) {
        currentEngineOption = eng;
    }
    
    public Object getCurrentEngineOption() {
        return currentEngineOption;
    }
    

    public void setAudioOption(Collection op) {
        audioOption =  new ArrayList(op);
    }
    
    public Collection getAudioOption() {
        return audioOption;
    }
    
    public void setCurrentAudioOption(Object op) {
        currentAudioOption = op;
    }
    
    public Object getCurrentAudioOption() {
        return currentAudioOption;
    }
    
    public void setSecuritySystem(boolean security) {
        securitySystem = security;
    }
    
    public boolean getSecuritySystem() {
        return securitySystem;
    }
    
    public void setSecuritySystemSelected(boolean security) {
        securitySystemSelected = security;
    }

    public boolean getSecuritySystemSelected() {
        return securitySystemSelected;
    }

    public void setGps(boolean g) {
        gps = g;
    }
    
    public boolean getGps() {
        return gps;
    }

    public boolean getGpsSelected() {
        return gpsSelected;
    }

    public void setGpsSelected(boolean g) {
        gpsSelected = g;
    }
    
    public void setCarTitle(String title) {
        carTitle = title;
    }
    
    public String getCarTitle() {
        return carTitle;
    }

    public void setCarDesc(String desc) {
        carDesc = desc;
    }
    
    public String getCarDesc() {
        return carDesc;
    }    
    
    public void setCarCurrentPrice(String cp) {
        currentPrice = cp;
    }
    
    public String getCarCurrentPrice() {
        return currentPrice;
    }

    public void setPackagePrice(String pp) {
        packagePrice = pp;
    }

    public String getPackagePrice() {
        return packagePrice;
    }    
    
    public void setCarBasePrice(String bp) {
        basePrice = bp;
    }
    
    public String getCarBasePrice() {
        return basePrice;
    }
    
    public void setCurrentPackage(String pack) {
        currentPackage = pack;
    }

    public String getCurrentPackage() {
        return currentPackage;
    }    
}