/*
 * Copyright 2002, 2003 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or
 * without modification, are permitted provided that the following
 * conditions are met:
 * 
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 * 
 * - Redistribution in binary form must reproduce the above
 *   copyright notice, this list of conditions and the following
 *   disclaimer in the documentation and/or other materials
 *   provided with the distribution.
 *    
 * Neither the name of Sun Microsystems, Inc. or the names of
 * contributors may be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *  
 * This software is provided "AS IS," without a warranty of any
 * kind. ALL EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND
 * WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE HEREBY
 * EXCLUDED. SUN AND ITS LICENSORS SHALL NOT BE LIABLE FOR ANY
 * DAMAGES OR LIABILITIES SUFFERED BY LICENSEE AS A RESULT OF OR
 * RELATING TO USE, MODIFICATION OR DISTRIBUTION OF THIS SOFTWARE OR
 * ITS DERIVATIVES. IN NO EVENT WILL SUN OR ITS LICENSORS BE LIABLE
 * FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR DIRECT, INDIRECT,
 * SPECIAL, CONSEQUENTIAL, INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER
 * CAUSED AND REGARDLESS OF THE THEORY OF LIABILITY, ARISING OUT OF
 * THE USE OF OR INABILITY TO USE THIS SOFTWARE, EVEN IF SUN HAS
 * BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 *  
 * You acknowledge that this software is not designed, licensed or
 * intended for use in the design, construction, operation or
 * maintenance of any nuclear facility.
 */


package carshop;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.StringTokenizer;

import javax.faces.validator.Validator;
import javax.faces.context.FacesContext;
import javax.faces.component.UIComponent;
import javax.faces.component.UIOutput;
import javax.faces.context.MessageResources;
import javax.faces.application.Application;
import javax.faces.FactoryFinder;
import javax.faces.application.ApplicationFactory;
import javax.faces.application.Message;


public class FormatValidator implements Validator {
    
    public static final String FORMAT_INVALID_MESSAGE_ID = "carshop.Format_Invalid";
    private ArrayList formatPatternsList = null;
    private String formatPatterns = null;
    
    /** Creates a new instance of FormatValidator */
    public FormatValidator() {
        super();
    }
    
    public FormatValidator(String formatPatterns) {
        super();
        this.formatPatterns = formatPatterns;
        parseFormatPatterns();
    }
    
    public String getFormatPatterns() {
        return (this.formatPatterns);
    }
    
    public void setFormatPatterns(String formatPatterns) {
        this.formatPatterns = formatPatterns;
        parseFormatPatterns();
    }
    
    public void parseFormatPatterns() {
        if (formatPatterns == null || formatPatterns.length() == 0 ) {
            return;
        }
        
        if (formatPatternsList != null ) {
            return;
        } else {
            formatPatternsList = new ArrayList();
        }
        StringTokenizer st =  new StringTokenizer(formatPatterns, "|");
        while (st.hasMoreTokens()) {
            String token = st.nextToken();
            formatPatternsList.add(token);
        }
    }
    

    
    public void validate(FacesContext context, UIComponent component) {
        boolean valid = false;
        
        if ((context == null) || (component == null)) {
            throw new NullPointerException();
        }
        
        if (!(component instanceof UIOutput)) {
            return;
        }    
     
        if ( formatPatternsList == null ) {
            component.setValid(true);
            return;
        }
        
        String value = (((UIOutput)component).getValue()).toString();
        Iterator patternIt = formatPatternsList.iterator();
        while (patternIt.hasNext()) {
            valid = isFormatValid(((String)patternIt.next()), value);
            if (valid) {
                break;
            }
        }
        if (valid) {
            component.setValid(true);
        } else {
            component.setValid(false);
            Message errMsg = getMessageResources().getMessage(context, FORMAT_INVALID_MESSAGE_ID, (new Object[] {formatPatterns}));
            context.addMessage(component, errMsg);
        }
    }
    

    protected boolean isFormatValid(String pattern, String value) {
        boolean valid = true;
        // if there is no pattern to match then value is valid
        if (pattern == null || pattern.length() == 0 ) {
            return true;
        }
        // if the value is null or a zero length string return false.
        if ( value == null || value.length() == 0 ) {
            return false;
        }
        // if the length of the value is not equal to the length of the
        // pattern string then the value is not valid.
        if (value.length() != pattern.length()) {
            return false;
        }
        value = value.trim();

        char[] input = value.toCharArray();
        char[] fmtpattern = pattern.toCharArray();
        for ( int i = 0; i < fmtpattern.length; ++i ) {
            if (!(Character.isDigit(input[i]))) {
                valid = false;
            }
        }
        return valid;
    }    
    
    
    public synchronized MessageResources getMessageResources() {
        MessageResources carResources = null;
        ApplicationFactory aFactory = (ApplicationFactory)FactoryFinder.getFactory(FactoryFinder.APPLICATION_FACTORY);
        Application application = aFactory.getApplication();
	carResources = application.getMessageResources("carShopResources");
        return (carResources);
    }    
}