/*
 * Copyright 2002, 2003 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or
 * without modification, are permitted provided that the following
 * conditions are met:
 * 
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 * 
 * - Redistribution in binary form must reproduce the above
 *   copyright notice, this list of conditions and the following
 *   disclaimer in the documentation and/or other materials
 *   provided with the distribution.
 *    
 * Neither the name of Sun Microsystems, Inc. or the names of
 * contributors may be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *  
 * This software is provided "AS IS," without a warranty of any
 * kind. ALL EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND
 * WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE HEREBY
 * EXCLUDED. SUN AND ITS LICENSORS SHALL NOT BE LIABLE FOR ANY
 * DAMAGES OR LIABILITIES SUFFERED BY LICENSEE AS A RESULT OF OR
 * RELATING TO USE, MODIFICATION OR DISTRIBUTION OF THIS SOFTWARE OR
 * ITS DERIVATIVES. IN NO EVENT WILL SUN OR ITS LICENSORS BE LIABLE
 * FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR DIRECT, INDIRECT,
 * SPECIAL, CONSEQUENTIAL, INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER
 * CAUSED AND REGARDLESS OF THE THEORY OF LIABILITY, ARISING OUT OF
 * THE USE OF OR INABILITY TO USE THIS SOFTWARE, EVEN IF SUN HAS
 * BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 *  
 * You acknowledge that this software is not designed, licensed or
 * intended for use in the design, construction, operation or
 * maintenance of any nuclear facility.
 */


package carshop;

import java.util.ResourceBundle;

import javax.faces.event.ValueChangedListener;
import javax.faces.event.PhaseId;
import javax.faces.event.ValueChangedEvent;
import javax.faces.context.FacesContext;
import javax.faces.application.Application;
import javax.faces.application.ApplicationFactory;
import javax.faces.FactoryFinder;
import javax.faces.el.ValueBinding;


public class PackageValueChanged implements ValueChangedListener {
    
    public PackageValueChanged() {
    }
    
    public PhaseId getPhaseId() {
        return PhaseId.PROCESS_VALIDATIONS;
    }
    
    public void processValueChanged(ValueChangedEvent vEvent) {
        try {
            String componentId = vEvent.getComponent().getComponentId();
            FacesContext context = FacesContext.getCurrentInstance();
            String currentPrice;
            int cPrice = 0;
            ApplicationFactory factory = (ApplicationFactory)FactoryFinder.getFactory("javax.faces.application.ApplicationFactory");
            Application application = factory.getApplication();
            ValueBinding binding = application.getValueBinding("CurrentOptionServer.carCurrentPrice");
            currentPrice = (String)binding.getValue(context);
            cPrice = Integer.parseInt(currentPrice);
            
            if ((componentId.equals("currentEngine")) || (componentId.equals("currentAudio"))) {
                    
                cPrice = cPrice - (this.getPriceFor((String)vEvent.getOldValue()));
                cPrice = cPrice + (this.getPriceFor((String)vEvent.getNewValue()));
            } else {
                Boolean optionSet = (Boolean)vEvent.getNewValue();
                cPrice = calculatePrice(componentId, optionSet, cPrice); 
            }
            
            currentPrice = Integer.toString(cPrice);
            ValueBinding resultBinding = application.getValueBinding("CurrentOptionServer.carCurrentPrice");
            resultBinding.setValue(context, currentPrice);

        } catch (NumberFormatException ignored) {
        }
    }
    
    public int calculatePrice(String optionKey, Boolean optionSet, int cPrice) {
        if (optionSet.equals(Boolean.TRUE)) {
            cPrice = cPrice + (this.getPriceFor(optionKey));
        } else {
            cPrice = cPrice - (this.getPriceFor(optionKey));
        }
        return cPrice;
    }
    
    

    public int getPriceFor(String option) {
        ResourceBundle rb = ResourceBundle.getBundle("carshop/Resources", (FacesContext.getCurrentInstance().getLocale()));

        if (option.equals("V4")) {
            return (100);
        }
        else if (option.equals("V6")) {
            return (300);
        }
        else if (option.equals("V8")) {
            return (500);
        }
        else if (option.equals((String)rb.getObject("Standard"))) {
            return (100);
        }
        else if (option.equals((String)rb.getObject("Premium"))) {
            return (200);
        }
        else if (option.equals("securitySystem")) {
            return (100);
        }
        else if (option.equals("gps")) {
            return (200);
        }
        else return 0;
        
    }
    
    
}